@@ -1,4 +1,5 @@
 import threading
+
 from sqlalchemy import create_engine, text
 from sqlalchemy.orm import sessionmaker
 
@@ -143,6 +144,23 @@ class DatabaseClient:
             logger.error(e)
             raise DBException("cannot close: {exception}".format(exception=e))
 
+    def insert_return(self, sql: str, param_dict: dict):
+        """
+        insert_return several SQLs
+
+        :param_dict: dict, sql: str to be executed
+        """
+        try:
+            logger.debug("executing param_dict: {param_dict}".format(param_dict=param_dict))
+            logger.debug("executing sql: {sql}".format(sql=sql))
+            result = self.session.execute(text(sql), param_dict)
+            self.session.commit()
+            return result.fetchone()
+        except Exception as e:
+            self.session.rollback()
+            logger.error(e)
+            raise DBException("cannot insert return: {exception}".format(exception=e))
+
 
 if __name__ == '__main__':
     conn = DatabaseClient(
