@@ -36,3 +36,6 @@ class RedisConnection:
             return self.__redis.delete(key)
         else:
             return None
+
+    def get_conn(self):
+        return self.__redis
